==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/autoaway/translations/autoaway_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autoaway</source>
        <translation>Auto-zajęty</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Sprawdzaj bezczynność co</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Włącz auto-zajęty</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Ustaw status na &apos;Zajęty&apos; po</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Włącz auto-niewidzialny</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Ustaw status na &apos;Niewidzialny&apos; po</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Włącz auto-rozłączenie</translation>
    </message>
    <message>
        <source>Disconnect after</source>
        <translation>Rozłącz po</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zastąp</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nowy opis</translation>
    </message>
    <message>
        <source>Parse AutoStatus</source>
        <translation>Parsuj AutoStatus</translation>
    </message>
    <message>
        <source>Enable auto extended away</source>
        <translation>Włącz auto-nieobecny</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Ustaw status na &apos;Nieobecny&apos; po</translation>
    </message>
    <message>
        <source>Auto refresh status</source>
        <translation>Automatycznie odświeżaj status</translation>
    </message>
    <message numerus="yes">
        <source>[every] %n second(s)</source>
        <translation>
            <numerusform>[co] %n sekundę</numerusform>
            <numerusform>[co] %n sekundy</numerusform>
            <numerusform>[co] %n sekund</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>[after] %n second(s)</source>
        <translation>
            <numerusform>[po] %n sekundzie</numerusform>
            <numerusform>[po] %n sekundach</numerusform>
            <numerusform>[po] %n sekundach</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Nie zmieniaj</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Dodaj na przodzie</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Dodaj z tyłu</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Nie odświeżaj</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/autoaway/translations/autoaway_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autoaway</source>
        <translation>Auto-zajęty</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Sprawdzaj bezczynność co</translation>
    </message>
    <message>
        <source>Enable autoaway</source>
        <translation>Włącz auto-zajęty</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Ustaw status na &apos;Zajęty&apos; po</translation>
    </message>
    <message>
        <source>Enable autoinvisible</source>
        <translation>Włącz auto-niewidzialny</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Ustaw status na &apos;Niewidzialny&apos; po</translation>
    </message>
    <message>
        <source>Enable autodisconnect</source>
        <translation>Włącz auto-rozłączenie</translation>
    </message>
    <message>
        <source>Disconnect after</source>
        <translation>Rozłącz po</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zastąp</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nowy opis</translation>
    </message>
    <message>
        <source>Parse AutoStatus</source>
        <translation>Parsuj AutoStatus</translation>
    </message>
    <message>
        <source>Enable auto extended away</source>
        <translation>Włącz auto-nieobecny</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Ustaw status na &apos;Nieobecny&apos; po</translation>
    </message>
    <message>
        <source>Auto refresh status</source>
        <translation>Automatycznie odświeżaj status</translation>
    </message>
    <message numerus="yes">
        <source>[every] %n second(s)</source>
        <translation><numerusform>[co] %n sekundę</numerusform><numerusform>[co] %n sekundy</numerusform><numerusform>[co] %n sekund</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>[after] %n second(s)</source>
        <translation><numerusform>[po] %n sekundzie</numerusform><numerusform>[po] %n sekundach</numerusform><numerusform>[po] %n sekundach</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekunda</numerusform><numerusform>%n sekundy</numerusform><numerusform>%n sekund</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Nie zmieniaj</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Dodaj na przodzie</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Dodaj z tyłu</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Nie odświeżaj</translation>
    </message>
</context>
</TS>
